"use strict";
/*
  This program and the accompanying materials are
  made available under the terms of the Eclipse Public License v2.0 which accompanies
  this distribution, and is available at https://www.eclipse.org/legal/epl-v20.html

  SPDX-License-Identifier: EPL-2.0

  Copyright Contributors to the Zowe Project.
*/
exports.__esModule = true;
var express = require('express');
var Promise = require('bluebird');
var BrowserPreferencesDataservice = /** @class */ (function () {
    function BrowserPreferencesDataservice(context) {
        this.context = context;
        var router = express.Router();
        router.use(function noteRequest(req, res, next) {
            context.logger.info('ZWED0017I', req.method); /*context.logger.info('Saw request, method=' + req.method);*/
            next();
        });
        context.addBodyParseMiddleware(router);
        router.post('/', function (req, res) {
            var requestBody = req.body;
            var languageFromClient = req.body ? req.body.language : null;
            var localFromClient = req.body ? req.body.locale : null;
            var savedPreferences = {};
            var responseBody = {
                '_objectType': 'com.rs.mvd.ng2desktop.browserPreferences',
                '_metaDataVersion': '1.0.0',
                'requestBody': req.body,
                'requestURL': req.originalUrl,
                'savedPreferences': savedPreferences
            };
            if (requestBody) {
                for (var _i = 0, _a = Object.keys(requestBody); _i < _a.length; _i++) {
                    var key = _a[_i];
                    var value = requestBody[key];
                    var expirationDate = new Date();
                    // If the key is there and has a value: set the cookie for 100 years (effectively permanent)
                    // If the key is there but the value is null: clear the cookie by making it expire in the past
                    if (value) {
                        expirationDate.setFullYear(expirationDate.getFullYear() + 100);
                    }
                    else {
                        expirationDate.setFullYear(expirationDate.getFullYear() - 100);
                        value = 'expire';
                    }
                    var maxAge = expirationDate.getTime();
                    res.cookie(key, value, { maxAge: maxAge });
                    savedPreferences[key] = {
                        'value': value,
                        'maxAge': maxAge
                    };
                }
            }
            res.status(200).json(responseBody);
        });
        this.router = router;
    }
    BrowserPreferencesDataservice.prototype.getRouter = function () {
        return this.router;
    };
    return BrowserPreferencesDataservice;
}());
exports.browserPreferencesRouter = function (context) {
    return new Promise(function (resolve, reject) {
        var dataservice = new BrowserPreferencesDataservice(context);
        resolve(dataservice.getRouter());
    });
};
//# sourceMappingURL=browserPreferences.js.map